==> qxmpp_0.2.0.orig.tar.gz: qxmpp-0.2.0/src/QXmppConstants.h <==
/*
 * Copyright (C) 2008-2010 The QXmpp developers
 *
 * Author:
 *  Manjeet Dahiya
 *
 * Source:
 *  http://code.google.com/p/qxmpp
 *
 * This file is a part of QXmpp library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 */


#ifndef QXMPPCONSTANTS_H
#define QXMPPCONSTANTS_H

extern const char* ns_stream;
extern const char* ns_client;
extern const char* ns_server;
extern const char* ns_server_dialback;
extern const char* ns_roster;
extern const char* ns_tls;
extern const char* ns_sasl;
extern const char* ns_bind;
extern const char* ns_session;
extern const char* ns_stanza;
extern const char* ns_vcard;
extern const char* ns_auth;
extern const char* ns_authFeature;
extern const char* ns_capabilities;
extern const char* ns_disco_info;
extern const char* ns_disco_items;
extern const char* ns_ibb;
extern const char* ns_rpc;
extern const char* ns_ping;
extern const char *ns_conference;
extern const char *ns_delayed_delivery;
extern const char *ns_legacy_delayed_delivery;
extern const char *ns_muc;
extern const char *ns_muc_admin;
extern const char *ns_muc_owner;
extern const char *ns_muc_user;
extern const char *ns_chat_states;
extern const char *ns_stream_initiation;
extern const char *ns_stream_initiation_file_transfer;
extern const char *ns_feature_negotiation;
extern const char *ns_bytestreams;
extern const char *ns_version;
extern const char *ns_data;
extern const char *ns_jingle;
extern const char* ns_jingle_ice_udp;
extern const char* ns_jingle_raw_udp;
extern const char *ns_jingle_rtp;
extern const char *ns_jingle_rtp_audio;
extern const char *ns_jingle_rtp_video;

#endif // QXMPPCONSTANTS_H

==> qxmpp_0.3.0.orig.tar.gz: qxmpp-0.3.0/src/QXmppConstants.h <==
/*
 * Copyright (C) 2008-2011 The QXmpp developers
 *
 * Author:
 *  Manjeet Dahiya
 *
 * Source:
 *  http://code.google.com/p/qxmpp
 *
 * This file is a part of QXmpp library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 */


#ifndef QXMPPCONSTANTS_H
#define QXMPPCONSTANTS_H

extern const char* ns_stream;
extern const char* ns_client;
extern const char* ns_server;
extern const char* ns_server_dialback;
extern const char* ns_roster;
extern const char* ns_tls;
extern const char* ns_sasl;
extern const char* ns_bind;
extern const char* ns_session;
extern const char* ns_stanza;
extern const char* ns_vcard;
extern const char* ns_vcard_update;
extern const char* ns_auth;
extern const char* ns_authFeature;
extern const char* ns_capabilities;
extern const char* ns_compress;
extern const char* ns_compressFeature;
extern const char* ns_disco_info;
extern const char* ns_disco_items;
extern const char* ns_ibb;
extern const char* ns_rpc;
extern const char* ns_ping;
extern const char *ns_conference;
extern const char *ns_delayed_delivery;
extern const char *ns_legacy_delayed_delivery;
extern const char *ns_muc;
extern const char *ns_muc_admin;
extern const char *ns_muc_owner;
extern const char *ns_muc_user;
extern const char *ns_chat_states;
extern const char *ns_stream_initiation;
extern const char *ns_stream_initiation_file_transfer;
extern const char *ns_feature_negotiation;
extern const char *ns_bytestreams;
extern const char *ns_version;
extern const char *ns_data;
extern const char *ns_jingle;
extern const char* ns_jingle_ice_udp;
extern const char* ns_jingle_raw_udp;
extern const char *ns_jingle_rtp;
extern const char *ns_jingle_rtp_audio;
extern const char *ns_jingle_rtp_video;
extern const char *ns_entity_time;

#endif // QXMPPCONSTANTS_H
